==> cineast-proto-0.1.0-sources.jar: main/java/org/vitrivr/cineast/api/grpc/CineastExtractGrpc.java <==
package org.vitrivr.cineast.api.grpc;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.33.1)",
    comments = "Source: cineast.proto")
public final class CineastExtractGrpc {

  private CineastExtractGrpc() {}

  public static final String SERVICE_NAME = "org.vitrivr.cineast.api.grpc.CineastExtract";

  // Static method descriptors that strictly reflect the proto.
  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CineastExtractStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractStub>() {
        @java.lang.Override
        public CineastExtractStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractStub(channel, callOptions);
        }
      };
    return CineastExtractStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CineastExtractBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractBlockingStub>() {
        @java.lang.Override
        public CineastExtractBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractBlockingStub(channel, callOptions);
        }
      };
    return CineastExtractBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CineastExtractFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractFutureStub>() {
        @java.lang.Override
        public CineastExtractFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractFutureStub(channel, callOptions);
        }
      };
    return CineastExtractFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class CineastExtractImplBase implements io.grpc.BindableService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .build();
    }
  }

  /**
   */
  public static final class CineastExtractStub extends io.grpc.stub.AbstractAsyncStub<CineastExtractStub> {
    private CineastExtractStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class CineastExtractBlockingStub extends io.grpc.stub.AbstractBlockingStub<CineastExtractBlockingStub> {
    private CineastExtractBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class CineastExtractFutureStub extends io.grpc.stub.AbstractFutureStub<CineastExtractFutureStub> {
    private CineastExtractFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractFutureStub(channel, callOptions);
    }
  }


  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final CineastExtractImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(CineastExtractImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class CineastExtractBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CineastExtractBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.vitrivr.cineast.api.grpc.CineastGrpc.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CineastExtract");
    }
  }

  private static final class CineastExtractFileDescriptorSupplier
      extends CineastExtractBaseDescriptorSupplier {
    CineastExtractFileDescriptorSupplier() {}
  }

  private static final class CineastExtractMethodDescriptorSupplier
      extends CineastExtractBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    CineastExtractMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CineastExtractGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CineastExtractFileDescriptorSupplier())
              .build();
        }
      }
    }
    return result;
  }
}

==> cineast-proto-0.1.2-sources.jar: main/java/org/vitrivr/cineast/api/grpc/CineastExtractGrpc.java <==
package org.vitrivr.cineast.api.grpc;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.44.0)",
    comments = "Source: cineast.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class CineastExtractGrpc {

  private CineastExtractGrpc() {}

  public static final String SERVICE_NAME = "org.vitrivr.cineast.api.grpc.CineastExtract";

  // Static method descriptors that strictly reflect the proto.
  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CineastExtractStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractStub>() {
        @java.lang.Override
        public CineastExtractStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractStub(channel, callOptions);
        }
      };
    return CineastExtractStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CineastExtractBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractBlockingStub>() {
        @java.lang.Override
        public CineastExtractBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractBlockingStub(channel, callOptions);
        }
      };
    return CineastExtractBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CineastExtractFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastExtractFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastExtractFutureStub>() {
        @java.lang.Override
        public CineastExtractFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastExtractFutureStub(channel, callOptions);
        }
      };
    return CineastExtractFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class CineastExtractImplBase implements io.grpc.BindableService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .build();
    }
  }

  /**
   */
  public static final class CineastExtractStub extends io.grpc.stub.AbstractAsyncStub<CineastExtractStub> {
    private CineastExtractStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class CineastExtractBlockingStub extends io.grpc.stub.AbstractBlockingStub<CineastExtractBlockingStub> {
    private CineastExtractBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class CineastExtractFutureStub extends io.grpc.stub.AbstractFutureStub<CineastExtractFutureStub> {
    private CineastExtractFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastExtractFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastExtractFutureStub(channel, callOptions);
    }
  }


  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final CineastExtractImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(CineastExtractImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class CineastExtractBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CineastExtractBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.vitrivr.cineast.api.grpc.CineastGrpc.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CineastExtract");
    }
  }

  private static final class CineastExtractFileDescriptorSupplier
      extends CineastExtractBaseDescriptorSupplier {
    CineastExtractFileDescriptorSupplier() {}
  }

  private static final class CineastExtractMethodDescriptorSupplier
      extends CineastExtractBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    CineastExtractMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CineastExtractGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CineastExtractFileDescriptorSupplier())
              .build();
        }
      }
    }
    return result;
  }
}
